package cn.sh.stc.sict.cloud.common.core.util;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.convert.Convert;
import cn.sh.stc.sict.cloud.common.core.constant.Constant;
import cn.sh.stc.sict.cloud.common.core.dto.XSZYUserInfo;
import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;
import ngari.openapi.Client;
import ngari.openapi.JSONResponseBean;
import ngari.openapi.Request;
import ngari.openapi.Response;

/**
 * 医院公众号工具类
 * <p>
 * 注意事项：
 * 1.医院编码是否传递
 * 2.手机号必须有，作为用户身份的唯一标识
 */
@Slf4j
@UtilityClass
public class WoaUtil {

    // 香山中医医院公众号用户信息获取接口地址（纳里）
    private final static String XSZY_USER_URL = "https://openapi.ngarihealth.com/openapi/gateway";

    // 接口授权信息
    private final static String APP_KEY = "ngari635f7f4b0e980e63";
    private final static String APP_SECRET = "0e980e634196fcde";

    // 获取用户信息服务ID
    private final static String SERVICE_ID = "openapi.authenticationService";
    // 获取用户信息方法
    private final static String METHOD = "apiGetUserInfo";

    // 响应头请求唯一ID
    private final static String RESPONSE_HEADER_REQUEST_ID = "X-Ca-Request-Id";

    // 香山中医医院编码
    private final static String XSZY_HOSPITAL_CODE = "42502905200";

    /**
     * 获取用户信息
     *
     * @param ngCode 纳里授权码
     * @return
     */
    public XSZYUserInfo getXszyUserInfo(String ngCode) {

        //如果开启加密，则必填
        String encodingAesKey = "";
        Client client = new Client(XSZY_USER_URL, APP_KEY, APP_SECRET, encodingAesKey);

        try {
            // 入参说明[授权码，是否回调，拓展参数]
            Request request = new Request(SERVICE_ID, METHOD, ListUtil.toList(ngCode, false, null));
            Response response = client.execute(request);
            if (response.isSuccess()) {
                JSONResponseBean result = response.getJsonResponseBean();
                XSZYUserInfo xszyUserInfo = Convert.convert(XSZYUserInfo.class, result.getBody());
                // 设置医院编码
                xszyUserInfo.setHospitalCode(XSZY_HOSPITAL_CODE);
                return xszyUserInfo;
            } else {
                log.error("香山中医医院公众号token获取用户信息异常-1，requestId = [{}]，caError = [{}]，error = [{}]", response.getHeader(RESPONSE_HEADER_REQUEST_ID), response.getCaErrorMsg(), response.getErrorMessage());
                return null;
            }
        } catch (Exception ex) {
            log.error("香山中医医院公众号token获取用户信息异-2！");
            log.error(ex.getMessage(), ex);
            return null;
        }
    }

}
